@@ -1,5 +1,5 @@
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -10,6 +10,7 @@ in the Eclipse Public License, Version 2.0 are satisfied:
       GNU General Public License, Version 2.0 or later.
 ---------------------------------------------------------------------------- */
 # include <cstring>
+# include <string>
 # include <cppad/utility/vector.hpp>
 
 /*
@@ -22,19 +23,20 @@ $spell
     sparse_jacobian
 $$
 
-$section sacado Speed: sparse_jacobian$$
+$section Sacado Speed: sparse_jacobian$$
 
 $srccode%cpp% */
 // A sacado version of this test is not yet available
 bool link_sparse_jacobian(
+    const std::string&               job      ,
     size_t                           size     ,
     size_t                           repeat   ,
     size_t                           m        ,
     const CppAD::vector<size_t>&     row      ,
     const CppAD::vector<size_t>&     col      ,
-          CppAD::vector<double>&     x        ,
-          CppAD::vector<double>&     jacobian ,
-          size_t&                    n_sweep  )
+    CppAD::vector<double>&           x        ,
+    CppAD::vector<double>&           jacobian ,
+    size_t&                          n_color  )
 {
     return false;
 }
