@@ -1,5 +1,5 @@
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-18 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -14,8 +14,10 @@ in the Eclipse Public License, Version 2.0 are satisfied:
 
 extern bool implicit_ctor(void);
 extern bool prefer_reverse(void);
-extern bool multi_atomic(void);
-extern bool multi_checkpoint(void);
+extern bool multi_atomic_two(void);
+extern bool multi_atomic_three(void);
+extern bool multi_chkpoint_one(void);
+extern bool multi_chkpoint_two(void);
 
 int main(void)
 {   std::string group = "test_more/cppad_for_tmb";
@@ -26,8 +28,10 @@ int main(void)
 
     Run( implicit_ctor,            "implicit_ctor"          );
     Run( prefer_reverse,           "prefer_reverse"         );
-    Run( multi_atomic,             "multi_atomic"           );
-    Run( multi_checkpoint,         "multi_checkpoint"       );
+    Run( multi_atomic_two,         "multi_atomic_two"       );
+    Run( multi_atomic_three,       "multi_atomic_three"     );
+    Run( multi_chkpoint_one,       "multi_chkpoint_one"     );
+    Run( multi_chkpoint_two,       "multi_chkpoint_two"     );
 
     // check for memory leak
     bool memory_ok = CppAD::thread_alloc::free_all();
