@@ -1,5 +1,5 @@
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-18 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-21 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -14,7 +14,62 @@ in the Eclipse Public License, Version 2.0 are satisfied:
 # include <cppad/cppad.hpp>
 
 namespace { // BEGIN_EMPTY_NAMESPACE
+// ----------------------------------------------------------------------------
+bool vecad(void)
+{   bool ok = true;
+    using CppAD::AD;
 
+    // dynamic parameter vector
+    size_t np = 2;
+    size_t nx = 1;
+    size_t ny = 2;
+    CPPAD_TESTVECTOR(AD<double>) ap(np), ax(nx), ay(ny);
+    ap[0] = 0.0;
+    ap[1] = 1.0;
+    ax[0] = 2.0;
+
+    // declare independent variables, dynamic parameters, start recording
+    CppAD::Independent(ax, ap);
+
+    // Create a VecAD object
+    size_t nv = 2;
+    CppAD::VecAD<double> av(nv);
+    // ap[0] is either 0 or 1
+    av[ ap[0] ]       = ap[1];
+    av[ 1.0 - ap[0] ] = 2.0 * ap[1];
+
+    // create f: x -> y and stop tape recording
+    CppAD::AD<double> zero(0.0), one(1.0);
+    ay[0] = av[zero];
+    ay[1] = av[one];
+    CppAD::ADFun<double> f(ax, ay);
+
+    // zero order forward mode with p[0] = 0
+    CPPAD_TESTVECTOR(double) p(np), x(nx), y(ny);
+    p[0] = 0.0;
+    p[1] = 1.0;
+    x[0] = 2.0;
+    f.new_dynamic(p);
+    y   = f.Forward(0, x);
+    ok &= y[0] == p[1];
+    ok &= y[1] == 2.0 * p[1];
+
+    // zero order forward mode with p[0] = 1
+    p[0] = 1.0;
+    p[1] = 2.0;
+    x[0] = 3.0;
+    f.new_dynamic(p);
+    y   = f.Forward(0, x);
+    ok &= y[0] == 2.0 * p[1];
+    ok &= y[1] == p[1];
+    CPPAD_TESTVECTOR(double) dx(nx), dy(ny);
+    dx[0] = 1.0;
+    dy    = f.Forward(1, dx);
+    ok   &= dy[0] == 0.0;
+    ok   &= dy[1] == 0.0;
+
+    return ok;
+}
 // ----------------------------------------------------------------------------
 bool operator_with_variable(void)
 {   bool ok = true;
@@ -36,9 +91,7 @@ bool operator_with_variable(void)
         ax[j] = AD<double>(j + 1);
 
     // declare independent variables, dynamic parammeters, starting recording
-    size_t abort_op_index = 0;
-    bool   record_compare = true;
-    CppAD::Independent(ax, abort_op_index, record_compare, adynamic);
+    CppAD::Independent(ax, adynamic);
 
     // range space vector
     CPPAD_TESTVECTOR(AD<double>) ay(n);
@@ -187,15 +240,11 @@ bool dynamic_operator(void)
     ax[0] = 0.25;
 
     // declare independent variables, dynamic parammeters, starting recording
-    size_t abort_op_index = 0;
-    bool   record_compare = true;
-    CppAD::Independent(ax, abort_op_index, record_compare, adynamic);
+    CppAD::Independent(ax, adynamic);
 
     // range space vector
     size_t ny = 27;
-# if CPPAD_USE_CPLUSPLUS_2011
     ny += 6;
-# endif
     CPPAD_TESTVECTOR(AD<double>) ay(ny);
     size_t k = 0;
     // ----------------------------------------------------------
@@ -228,7 +277,6 @@ bool dynamic_operator(void)
     ++k;
     // ----------------------------------------------------------
     // 2011 standard math
-# if CPPAD_USE_CPLUSPLUS_2011
     ay[k] = asinh(adynamic[0]);
     ++k;
     ay[k] = acosh(adynamic[0] + 1.0);
@@ -241,7 +289,6 @@ bool dynamic_operator(void)
     ++k;
     ay[k] = log1p(adynamic[0]);
     ++k;
-# endif
     // ----------------------------------------------------------
     // binary
     ay[k]  = 2.0 + adynamic[0];
@@ -338,7 +385,6 @@ bool dynamic_operator(void)
     ++k;
     // ----------------------------------------------------------
     // 2011 standard math
-# if CPPAD_USE_CPLUSPLUS_2011
     check = asinh(dynamic[0]);
     ok   &= NearEqual(y[k], check, eps99, eps99);
     ++k;
@@ -357,7 +403,6 @@ bool dynamic_operator(void)
     check = std::log1p(dynamic[0]);
     ok   &= NearEqual(y[k], check, eps99, eps99);
     ++k;
-# endif
     // ----------------------------------------------------------
     // binary
     check = 2.0 + dynamic[0];
@@ -575,7 +620,7 @@ bool optimize_csum(void)
     f.Dependent(ax, ay);
     ok &= f.size_dyn_ind() == num_dyn_ind;
     ok &= f.size_dyn_par() == num_dyn_ind + 2;
-    // note that there is one phantom parameter at index zero that is not used
+    // constant parameters: nan, 3.0, 4.0, 5.0
     ok &= f.size_par()     == num_dyn_ind + 2 + 4;
     // -------------------------------------------------------------
     // vectors used for new_dynamic and Forward.
@@ -591,10 +636,11 @@ bool optimize_csum(void)
     ok   &= NearEqual(y[1], check, eps99, eps99);
     // -------------------------------------------------------------
     // optimize and re-test
-    f.optimize();
+    f.optimize(); // add the zero parameter
     ok &= f.size_dyn_ind() == num_dyn_ind;
     ok &= f.size_dyn_par() == num_dyn_ind + 1;
-    ok &= f.size_par()     == num_dyn_ind + 1 + 2;
+    // constant parameters: nan, zero, (3.0 - 4.0 + 5.0)
+    ok &= f.size_par()     == num_dyn_ind + 1 + 3;
     dynamic[0] = 0.3;
     dynamic[1] = 0.4;
     f.new_dynamic(dynamic);
@@ -628,7 +674,7 @@ bool dynamic_atomic(void)
     adynamic[0] = 1.0;
     adynamic[1] = 2.0;
     size_t abort_op_index = 0;
-    size_t record_compare = true;
+    bool   record_compare = true;
     Independent(ax, abort_op_index, record_compare, adynamic);
     atom_g(adynamic, ay);
     CppAD::ADFun<double> f(ax, ay);
@@ -667,7 +713,7 @@ bool dynamic_discrete(void)
     ADvector adynamic(1);
     adynamic[0] = 3.0;
     size_t abort_op_index = 0;
-    size_t record_compare = true;
+    bool   record_compare = true;
     Independent(ax, abort_op_index, record_compare, adynamic);
     ADvector ay(1);
     ay[0] = ax[0] * n_digits( adynamic[0] );
@@ -743,8 +789,8 @@ bool dynamic_optimize(void)
     f.Dependent(ax, ay);
     ok &= f.size_dyn_ind() == nd;
     ok &= f.size_dyn_par() == nd + 5;
-    // note that there is a phantom parameter at index zero that is not used
-    ok &= f.size_par()     == nd + 5 + 2; // one constant parameter 3.0
+    // constant parameters: nan, 3.0
+    ok &= f.size_par()     == nd + 5 + 2;
     // -------------------------------------------------------------
     // vectors used for new_dynamic and Forward.
     CPPAD_TESTVECTOR(double) dynamic(nd), x(nx), y(ny);
@@ -758,10 +804,11 @@ bool dynamic_optimize(void)
     ok   &= NearEqual(y[1], check, eps99, eps99);
     // -------------------------------------------------------------
     // optimize and re-test
-    f.optimize();
+    f.optimize(); // adds the zero parameter
     ok &= f.size_dyn_ind() == nd;
     ok &= f.size_dyn_par() == nd + 2;
-    ok &= f.size_par()     == nd + 2 + 2;
+    // constant parameters: nan, zero, 3.0
+    ok &= f.size_par()     == nd + 2 + 3;
     dynamic[0] = 6.0;
     f.new_dynamic(dynamic);
     y     = f.Forward(0, x);
@@ -779,7 +826,7 @@ bool dynamic_optimize(void)
 // ----------------------------------------------------------------------------
 bool new_dynamic(void)
 {   bool ok = true;
-    //
+    ok     &= vecad();
     ok     &= operator_with_variable();
     ok     &= dynamic_operator();
     ok     &= dynamic_compare();
